@@ -12,10 +12,15 @@ __all__ = ['IProblemConverter', 'convert_problem']
 
 import copy
 import os
-from formats import ProblemFormat, guess_format
-from error import *
+from coopr.opt.base.formats import ProblemFormat, guess_format
+from coopr.opt.base.error import *
 from pyutilib.component.core import *
 
+try:
+    unicode
+except NameError:
+    basestring = unicode = str
+
 
 class IProblemConverter(Interface):
 
@@ -36,15 +41,15 @@ def convert_problem( args, target_problem_type, valid_problem_types,
     """
 
     if len(valid_problem_types) == 0:
-        raise ConverterError, "No valid problem types"
+        raise ConverterError("No valid problem types")
 
     if not (target_problem_type is None or \
              target_problem_type in valid_problem_types):
         msg = "Problem type '%s' is not valid"
-        raise ConverterError, msg % str( target_problem_type )
+        raise ConverterError(msg % str( target_problem_type ))
 
     if len(args) == 0:
-        raise ConverterError, "Empty argument list"
+        raise ConverterError("Empty argument list")
 
     #
     # Setup list of source problem types
@@ -56,7 +61,7 @@ def convert_problem( args, target_problem_type, valid_problem_types,
             fname = tmp.split(os.sep)[-1]
         source_ptype = [guess_format(fname)]
         if source_ptype is [None]:
-            raise ConverterError, "Unknown suffix type: "+suffix
+            raise ConverterError("Unknown suffix type: "+suffix)
     else:
         source_ptype = args[0].valid_problem_types()
 
@@ -68,7 +73,6 @@ def convert_problem( args, target_problem_type, valid_problem_types,
         valid_ptypes.remove(target_problem_type)
         valid_ptypes = [target_problem_type]  + valid_ptypes
     if source_ptype[0] in valid_ptypes:
-        ##print "HERE",source_ptype, valid_ptypes
         valid_ptypes.remove(source_ptype[0])
         valid_ptypes = [source_ptype[0]]  + valid_ptypes
 
@@ -87,7 +91,6 @@ def convert_problem( args, target_problem_type, valid_problem_types,
         # one.
         #
             if s_ptype == ptype:
-                #print "yyy",args, ptype, None
                 return (args,ptype,None)
             #
             # Otherwise, try to convert
@@ -102,9 +105,8 @@ def convert_problem( args, target_problem_type, valid_problem_types,
                     tmpkw = kwds
                     tmpkw['capabilities'] = has_capability
                     problem_files, symbol_map = converter.apply(*tmp, **tmpkw)
-                    #print "X", problem_files
                     return problem_files, ptype, symbol_map
 
     msg = 'No conversion possible.  Source problem type: %s.  Valid target '  \
           'types: %s'
-    raise ConverterError, msg % (str(source_ptype[0]), map(str,valid_ptypes))
+    raise ConverterError(msg % (str(source_ptype[0]), map(str,valid_ptypes)))
