@@ -29,4 +29,4 @@ class AbstractResultsReader(ManagedPlugin):
         self.format=results_format
 
     def __call__(self, filename, res=None, suffixes=[]): #pragma:nocover
-        raise TypeError, "Method __call__ undefined in reader for format "+str(self.format)
+        raise TypeError("Method __call__ undefined in reader for format "+str(self.format))
