@@ -8,8 +8,8 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-from point import *
-import colin_xml_io
-import dakota_text_io
-from problem import *
-import solver
+from coopr.opt.blackbox.point import *
+import coopr.opt.blackbox.colin_xml_io
+import coopr.opt.blackbox.dakota_text_io
+from coopr.opt.blackbox.problem import *
+import coopr.opt.blackbox.solver
