@@ -17,10 +17,13 @@ Define the plugin for DAKOTA TEXT IO
 """
 
 import re
+
 from pyutilib.component.core import *
-from problem_io import *
 from pyutilib.math import as_number
 
+from coopr.opt.blackbox.problem_io import *
+
+
 class DakotaTextIO(SingletonPlugin):
     """The reader/writer for the DAKOTA TEXT IO Formats"""
 
@@ -71,6 +74,8 @@ class DakotaTextIO(SingletonPlugin):
             if asv & 4:
                 requests['Hessian'] = ''
         point.set_variables(vars)
+        #
+        INPUT.close()
         return point, requests
 
     def write(self, filename, response):
@@ -80,25 +85,25 @@ class DakotaTextIO(SingletonPlugin):
         OUTPUT = open(filename,"w")
         fno = 0
         if 'FunctionValue' in response:
-            print >>OUTPUT, response['FunctionValue'], self.funcname[fno]
+            OUTPUT.write("%s %s\n" % (response['FunctionValue'], self.funcname[fno]))
             fno += 1
         elif 'FunctionValues' in response:
             for val in response['FunctionValues']:
-                print >>OUTPUT, val, self.funcname[fno]
+                OUTPUT.write("%s %s\n" % (val, self.funcname[fno]))
                 fno += 1
         if 'NonlinearConstraintValues' in response and type(response['NonlinearConstraintValues']) is list:
             for val in response['NonlinearConstraintValues']:
-                print >>OUTPUT, val, self.funcname[fno]
+                OUTPUT.write("%s %s\n" % (val, self.funcname[fno]))
                 fno += 1
         if 'Gradient' in response and type(response['NonlinearConstraintValues']) is list:
             for val in response['Gradient']:
-                print >>OUTPUT, val,
-            print >>OUTPUT, ""
+                OUTPUT.write("%s " % val)
+            OUTPUT.write("\n")
         if 'Jacobian' in response and type(response['NonlinearConstraintValues']) is list:
             for grad in response['Jacobian']:
                 for val in grad:
-                    print >>OUTPUT, val,
-                print >>OUTPUT, ""
+                    OUTPUT.write("%s " % val)
+                OUTPUT.write("\n")
         if 'Hessian' in response and type(response['NonlinearConstraintValues']) is list:
-            print >>OUTPUT, "# ERROR: cannot print Hessian information"
+            OUTPUT.write("# ERROR: cannot print Hessian information")
         OUTPUT.close()
