@@ -14,6 +14,7 @@ Define COLIN point types
 
 __all__ = ['MixedIntVars', 'RealVars']
 
+import sys
 import copy
 import re
 import xml.dom.minidom
@@ -35,35 +36,35 @@ class MixedIntVars(object):
         #
         nreals = len(self.reals)
         self.reals = []
-        for j in xrange(nreals):
+        for j in range(nreals):
             self.reals.append( vlist[i] )
             i += 1
         #
         nints = len(self.ints)
         self.ints = []
-        for j in xrange(nints):
+        for j in range(nints):
             self.ints.append( vlist[i] )
             i += 1
         #
         nbits = len(self.bits)
         self.bits = []
-        for j in xrange(nbits):
+        for j in range(nbits):
             self.bits.append( vlist[i] )
             i += 1
 
     def display(self):
-        print "Reals",
+        sys.stdout.write("Reals ")
         for val in self.reals:
-            print val,
-        print ""
-        print "Integers",
+            sys.stdout.write(str(val)+" ")
+        sys.stdout.write("\n")
+        sys.stdout.write("Integers ")
         for val in self.ints:
-            print val,
-        print ""
-        print "Binary",
+            sys.stdout.write(str(val)+" ")
+        sys.stdout.write("\n")
+        sys.stdout.write("Binary ")
         for val in self.bits:
-            print val,
-        print ""
+            sys.stdout.write(str(val)+" ")
+        sys.stdout.write("\n")
 
     def process(self,node):
         self.reals=[]
@@ -105,8 +106,8 @@ class RealVars(object):
 
     def display(self):
         for val in self.vars:
-            print val,
-        print ""
+            sys.stdout.write(str(val)+' ')
+        sys.stdout.write('\n')
 
     def process(self,node):
         self.vars = []
