@@ -12,8 +12,8 @@ import pyutilib.component.core
 
 pyutilib.component.core.PluginGlobals.push_env( "coopr.opt" )
 
-from async_solver import *
-import manager
-import local
+from coopr.opt.parallel.async_solver import *
+import coopr.opt.parallel.manager
+import coopr.opt.parallel.local
 
 pyutilib.component.core.PluginGlobals.pop_env()
