@@ -13,7 +13,7 @@ __all__ = ['AsynchronousSolverManager', 'SolverManagerFactory']
 
 from pyutilib.component.core import *
 from pyutilib.component.config import ManagedPlugin
-from manager import *
+from coopr.opt.parallel.manager import *
 
 
 class ISolverManager(Interface):
