@@ -8,6 +8,5 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-#import OS
-import sol
-import res
+import coopr.opt.reader.sol
+import coopr.opt.reader.res
