@@ -1,7 +1,7 @@
 
 __all__ = ['GeneralResult']
 
-from container import *
+from coopr.opt.results.container import *
 from pyutilib.enum import Enum
 
 
