@@ -9,12 +9,18 @@
 
 __all__ = ['SolutionStatus', 'Solution', 'SolutionMap']
 
+import sys
 import math
-from container import *
+
+from six import iterkeys,itervalues,iteritems
+from six.moves import xrange
+
 from pyutilib.misc import Bunch
 from pyutilib.enum import Enum
 from pyutilib.math import as_number
 
+from coopr.opt.results.container import *
+
 default_print_options = Bunch(schema=False, sparse=True, num_solutions=None, ignore_time=False, ignore_defaults=False)
 
 SolutionStatus = Enum(
@@ -33,6 +39,20 @@ SolutionStatus = Enum(
 )
 
 
+try:
+    unicode
+except NameError:
+    basestring = unicode = str
+
+try:
+    long
+    intlist = (int, long)
+    numlist = (float, int, long)
+except:
+    intlist = (int, )
+    numlist = (float, int)
+
+
 class SolutionMap(MapContainer):
 
     def __init__(self, sparse=True):
@@ -48,7 +68,7 @@ class SolutionMap(MapContainer):
             return self.__dict__[tmp]
         except:
             pass
-        if type(name) in (int,long):
+        if type(name) in intlist:
             self.declare_item(tmp-1)
         else:
             self.declare_item(tmp)
@@ -120,7 +140,7 @@ class SolutionMap(MapContainer):
                 try:
                     var = self.__dict__[varname]
                     #var = dict.__getitem__(self, varname)
-                except Exception, err:
+                except Exception:
                     self.__dict__[varname]={}
                     var = self.__dict__[varname]
                     #dict.__setitem__(self, varname, {})
@@ -139,24 +159,16 @@ class SolutionMap(MapContainer):
         return name
 
     def _repn_(self, option):
-        #print "SOLUTION",self._active,self._required
         if not option.schema and not self._active and not self._required:
             return ignore
         if option.schema:
             self[0] = 1.0
             self[1] = 2.0
             self[2] = 3.0
-            #print dict.keys(self)
-            #print self.keys()
         tmp = {}
-        keys = self._names.keys()
-        keys.sort()
-        for i in keys:
+        for i in sorted(iterkeys(self._names)):
             key = self._names[i]
             rep = dict.__getitem__(self, key)._repn_(option)
-            #print "HERE",type(dict.__getitem__(self, key))
-            #print "HERE",repr(dict.__getitem__(self, key))
-            #print "HERE",rep
             if not rep == ignore:
                 if option.sparse and self._sparse:
                     trep = {}
@@ -164,7 +176,7 @@ class SolutionMap(MapContainer):
                         if tkey == 'Id':
                             trep[tkey] = rep[tkey]
                             continue
-                        if not type(rep[tkey]) in (float,int,long) or math.fabs(rep[tkey]) > 1e-16:
+                        if not type(rep[tkey]) in numlist or math.fabs(rep[tkey]) > 1e-16:
                             trep[tkey] = rep[tkey]
                     if len(trep.keys()) > 1:
                         tmp[key] = trep
@@ -176,7 +188,7 @@ class SolutionMap(MapContainer):
 
     def pprint(self, ostream, option, from_list=False, prefix="", repn=None):
         if isinstance(repn,basestring):
-            print >>ostream, repn
+            ostream.write(repn+'\n')
         else:
             MapContainer.pprint(self, ostream, option, from_list=from_list, prefix=prefix, repn=repn)
 
@@ -186,9 +198,7 @@ class SolutionMap(MapContainer):
         index = {}
         for key in repn:
             index[repn[key]['Id']] = key
-        keys = index.keys()
-        keys.sort()
-        for key in keys:
+        for key in sorted(iterkeys(index)):
             self.declare_item(index[key], id=key)
             for elt in repn[index[key]]:
                 if elt == 'Id':
@@ -205,15 +215,16 @@ class Solution(MapContainer):
         self.declare('status', value=SolutionStatus.unknown)
         self.declare('message')
 
+        self.declare('problem', value=SolutionMap(), active=False)
         self.declare('objective', value=SolutionMap(sparse=False), active=False)
-        self.declare('variable', value={})
+        self.declare('variable', value={}) 
         self.declare('constraint', value=SolutionMap())
 
         self._option = default_print_options
 
     def load(self, repn):
         # delete key from dictionary, call base class load, handle variable loading.
-        if repn.has_key("Variable"):
+        if "Variable" in repn:
             var_dict = repn["Variable"]
             del repn["Variable"]
             self.variable = var_dict
@@ -254,16 +265,16 @@ class SolutionSet(ListContainer):
     def pprint(self, ostream, option, prefix="", repn=None):
         if not option.schema and not self._active and not self._required:
             return ignore
-        print >>ostream, ""
-        print >>ostream, prefix+"-",
+        ostream.write("\n")
+        ostream.write(prefix+"- ")
         spaces=""
         for key in repn[0]:
-            print >>ostream, prefix+spaces+key+":",repn[0][key]
+            ostream.write(prefix+spaces+key+": "+str(repn[0][key])+'\n')
             spaces="  "
         i=0
         for i in xrange(len(self._list)):
             item = self._list[i]
-            print >>ostream, prefix+'-',
+            ostream.write(prefix+'- ')
             item.pprint(ostream, option, from_list=True, prefix=prefix+"  ", repn=repn[i+1])
 
     def load(self, repn):
