@@ -9,7 +9,7 @@ from coopr.opt import SolverResults
 
 def main():
     if len(sys.argv) > 1:
-        print "results_schema  - Print the predefined schema in a SolverResults object"
+        print("results_schema  - Print the predefined schema in a SolverResults object")
     options = Options(schema=True)
     r=SolverResults()
     repn = r._repn_(options)
