@@ -20,9 +20,9 @@ try:
     import cPickle as pickle
 except ImportError:
     import pickle
+import datetime
 import pyutilib.services
 import pyutilib.pyro
-import datetime
 
 
 class CooprMIPWorker(pyutilib.pyro.TaskWorker):
@@ -41,7 +41,7 @@ class CooprMIPWorker(pyutilib.pyro.TaskWorker):
         else:
            opt = coopr.opt.SolverFactory(data.opt)
         if opt is None:
-            raise ValueError, "Problem constructing solver `"+data.opt+"'"
+            raise ValueError("Problem constructing solver `"+data.opt+"'")
 
         opt.suffixes = data.suffixes
 
@@ -50,26 +50,25 @@ class CooprMIPWorker(pyutilib.pyro.TaskWorker):
         solver_options = data.solver_options
         del data.solver_options
         for key,value in solver_options.items():
-#            print "RECEIVED SOLVER OPTION="+key+" WITH VALUE="+str(value)
             setattr(opt.options,key,value)
 
         problem_filename_suffix = os.path.split(data.filename)[1]
         temp_problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix="."+problem_filename_suffix)
         OUTPUT=open(temp_problem_filename,'w')
-        print >>OUTPUT, data.file,
+        OUTPUT.write(data.file)
         OUTPUT.close()
 
         if data.warmstart_file is not None:
             warmstart_filename_suffix = os.path.split(data.warmstart_filename)[1]
             temp_warmstart_filename = pyutilib.services.TempfileManager.create_tempfile(suffix="."+warmstart_filename_suffix)
             OUTPUT=open(temp_warmstart_filename,'w')
-            print >>OUTPUT, data.warmstart_file
+            OUTPUT.write(str(data.warmstart_file)+'\n')
             OUTPUT.close()
             opt.warm_start_solve = True
             opt.warm_start_file_name = temp_warmstart_filename
 
         now = datetime.datetime.now()
-        print str(now) + ": Applying solver="+data.opt+" to solve problem="+temp_problem_filename
+        print(str(now) + ": Applying solver="+data.opt+" to solve problem="+temp_problem_filename)
         sys.stdout.flush()        
         results = opt.solve(temp_problem_filename, **data.kwds)
 
@@ -80,7 +79,7 @@ class CooprMIPWorker(pyutilib.pyro.TaskWorker):
         pyutilib.services.TempfileManager.pop()
 
         now = datetime.datetime.now()
-        print str(now) + ": Solve completed - number of solutions="+str(len(results.solution))
+        print(str(now) + ": Solve completed - number of solutions="+str(len(results.solution)))
         sys.stdout.flush()
 #        results.write()
 #        sys.stdout.flush()
