@@ -33,9 +33,9 @@ class Test(unittest.TestCase):
 
     def test_factory(self):
         reader = coopr.opt.ReaderFactory("sol")
-        soln = reader(currdir+"test4_sol.sol")
-        soln.write(filename=currdir+"factory.txt")
-        self.assertFileEqualsBaseline(currdir+"factory.txt", currdir+"test4_sol.txt")
+        soln = reader(currdir+"test4_sol.sol", suffixes=["dual"])
+        soln.write(filename=currdir+"factory.txt", format='json')
+        self.assertMatchesJsonBaseline(currdir+"factory.txt", currdir+"test4_sol.jsn")
 
 
 if __name__ == "__main__":
