@@ -19,6 +19,7 @@ import pyutilib.services
 import xml
 import pickle
 
+from six import iterkeys
 try:
     import yaml
     yaml_available=True
@@ -148,7 +149,7 @@ class Test(unittest.TestCase):
         self.soln.variable[2]["Value"]=0.0
         self.soln.variable[4]["Value"]=0.0
         pyutilib.misc.setup_redirect(currdir+"soln_pprint2.out")
-        print self.soln
+        print(self.soln)
         pyutilib.misc.reset_redirect()
         self.assertFileEqualsBaseline(currdir+"soln_pprint2.out", currdir+"soln_pprint2.txt")
 
@@ -163,7 +164,7 @@ class Test(unittest.TestCase):
         self.soln.variable[1]["Value"] = 0.0
         self.soln.variable[4]["Value"] =0.3
         self.soln.variable[4]["Slack"] = 0.4
-        self.assertEqual(self.soln.variable.keys(),[1,2,4])
+        self.assertEqual(list(iterkeys(self.soln.variable)),[1,2,4])
         self.assertEqual(self.soln.variable[1]["Value"],0.0)
         self.assertEqual(self.soln.variable[4]["Value"],0.3)
         self.assertEqual(self.soln.variable[4]["Slack"],0.4)
